<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\DDD\ValueObjects\CountryAndLanguage;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the name.
 *
 * @property-read string $value The raw value.
 */
final class Name implements \Stringable {
	/**
	 * The id value of the icon.
	 *
	 * @var string
	 */
	private readonly string $value;

	/**
	 * The constructor.
	 *
	 * @param mixed $value The name of the country.
	 * @throws \InvalidArgumentException If the id is not numeric or less than 1.
	 */
	public function __construct( mixed $value ) {
		if ( ! is_string( $value ) ) {
			throw new \InvalidArgumentException( 'The name must be a string.' );
		}
		$trimmed_value = trim( $value );
		if ( empty( $trimmed_value ) ) {
			throw new \InvalidArgumentException( 'The name must not be empty.' );
		}

		$this->value = $trimmed_value;
	}

	/**
	 * The magick getter.
	 *
	 * @param string $name The name of the property.
	 * @throws \InvalidArgumentException If the property does not exist.
	 */
	public function __get( string $name ): mixed {
		return match ( $name ) {
			'value' => $this->value,
			default => throw new \InvalidArgumentException( 'The property "' . esc_html( $name ) . '" does not exist.' ),
		};
	}

	/**
	 * The magick to string method.
	 */
	public function __toString(): string {
		return $this->value;
	}

	/**
	 * Returns the primary name.
	 */
	public function primary(): self {
		$comma_position = strpos( $this->value, ',' );
		if ( false !== $comma_position && $comma_position > 0 ) {
			return new self( substr( $this->value, 0, $comma_position ) );
		}

		return new self( $this->value );
	}
}
